pub struct TlsPolicy { /* private fields */ }Expand description
A TLS policy that enforces minimum version and cipher allowlists.
Implementations
Sourceimpl TlsPolicy
impl TlsPolicy
Sourcepub fn new(min_version: TlsVersion) -> Self
pub fn new(min_version: TlsVersion) -> Self
Creates a new TLS policy with the given minimum version.
Sourcepub fn with_allowed_ciphers(self, ciphers: Vec<CipherSuite>) -> Self
pub fn with_allowed_ciphers(self, ciphers: Vec<CipherSuite>) -> Self
Restricts the policy to only the specified cipher suites.
Sourcepub fn validate(
&self,
version: TlsVersion,
cipher: &CipherSuite,
) -> TlsValidationResult
pub fn validate( &self, version: TlsVersion, cipher: &CipherSuite, ) -> TlsValidationResult
Validates a connection’s TLS version and cipher suite against this policy.
Sourcepub fn validate_and_emit(
&self,
version: TlsVersion,
cipher: &CipherSuite,
sink: &dyn SecuritySink,
) -> TlsValidationResult
pub fn validate_and_emit( &self, version: TlsVersion, cipher: &CipherSuite, sink: &dyn SecuritySink, ) -> TlsValidationResult
Validates and emits a security event on violation.